package TNA_SL;

/**
 * The Branch class implements a list of Arcs in a directed graph. It is 
 * considerably more lightweight than the Digraph class; a Branch does not
 * maintain vertex perspectives. 
 */
public class Branch implements Comparable<Branch>{
	
	// ************************** PRIVATE FIELDS *****************************
	
	/**
	 * The list of directed Arcs composing this Branch.
	 */
	private Arc arcList[];
	
	// *************************** CONSTRUCTORS ******************************
	
	/**
	 * Construct a Branch object given a Digraph object.
	 * @param branch The Digraph object to be converted to a Branch
	 */
	public Branch(Digraph branch){
		this.arcList = new Arc[branch.arcSize()];
		for(int i=0; i < branch.arcSize(); i++)
			this.arcList[i] = branch.arcGet(i);
		return;
	}
	
	// ************************** PUBLIC METHODS *****************************
	
	/**
	 * Compare this Branch object to another branch.
	 * @param other the Branch being compared to 'this' one
	 * @return -1 if (this < other), 0 if this equals other; 1 otherwise
	 */
	public int compareTo(Branch other){
		if(this.getSize() > other.getSize())
			return 1;
		else if(this.getSize() < other.getSize())
			return -1;
		int compare, limit = Math.min(this.getSize(), other.getSize());
		for(int i=0; i < limit; i++){
			compare = this.getArc(i).compareTo(other.getArc(i));
			if(compare != 0)
				return compare;
		} // If list sizes are equal, begin comparing element-wise
		return 0;
	}
	
	/**
	 * Return a String representation of this Branch object.
	 * @return a String representation of this Branch object
	 */
	public String print(){
		String retString = "";
		for(int i=0; i < this.getSize(); i++)
			retString += this.getArc(i).print() + "\n";
		return retString;
	}
	
	/**
	 * Retrieve an Arc at a specified position in this Branch.
	 * @param index Integer position of the desired Arc
	 * @return The Arc at position 'index' in this Branch
	 */
	public Arc getArc(int index){
		return arcList[index];
	}
	
	/**
	 * Return the magnitude (number of Arcs) in this Branch.
	 * @return the number of Arcs this Branch object contains
	 */
	public int getSize(){
		return arcList.length;
	}
	
}
