package TNA_SL;

import java.util.*;

/**
 * The BranchCache object stores a sorted list of Branch objects.
 */
public class BranchCache{
	
	// ************************** PRIVATE FIELDS *****************************
	
	/**
	 * The 'branchList' field stores a sorted list of Branch objects.
	 */
	private List<Branch> branchList;
	
	// *************************** CONSTRUCTORS ******************************
	
	/**
	 * Construct an empty BranchCache object.
	 */
	public BranchCache(){
		this.branchList = new ArrayList<Branch>();
	}
	
	// ************************** PUBLIC METHODS *****************************
	
	/**
	 * Given a Digraph, convert it to a Branch, and test if that Branch already
	 * resides in this BranchCache. If it does not, then add it.
	 * @param d The Digraph which will be converted
	 * @return True if the Branch form of 'd' was already contained in this
	 * BranchCache object. Otherwise, false, implying its addition. 
	 */
	public boolean branchInCache(Digraph d){
		Branch newBranch = new Branch(d);
		int index = Collections.binarySearch(this.branchList, newBranch);
		if(index >= 0)
			return true;
		this.branchList.add((index+1)*-1, newBranch);
		return false;
	}
	
	/**
	 * Return a string representation of this BranchCache object.
	 * @return a string representation of this BranchCache object
	 */
	public String print(){
		String retString = "";
		for(int i=0; i < this.branchList.size(); i++)
			retString += this.branchList.get(i).print() + "\n";
		return retString;
	}
	
}
