
package interfaces;

/**
 * The RMDBInterface interface specifies those methods which any reputation
 * storage class should implement to conform with the QKeyNote standards.
 */
public interface RMDBInterface{
	
	/**
	 * Add information about an interaction between two users. 
	 * @param source String ID of user who is submitting the feedback
	 * @param target String ID of user who feedback is being submitted about
	 * @param feedback True to indicate positive feedback; false, otherwise
	 */
	public void addFeedback(String source, String target, boolean feedback);
	
	/**
	 * Retrieve the number of positive interactions between two users.
	 * @param source String ID of source user of the desired relationship
	 * @param target String ID of target user of the desired relationship
	 * @return Number of positive interactions in [source->target] relationship
	 */
	public int getPos(String source, String target);
	
	/**
	 * Retrieve the number of negative interactions between two users.
	 * @param source String ID of source user of the desired relationship
	 * @param target String ID of target user of the desired relationship
	 * @return Number of negative interactions in [source->target] relationship
	 */
	public int getNeg(String source, String target);
	
	/**
	 * Retrieve a list of all users contained in implementing class
	 * @return An array of String objects, each being a unique user ID
	 */
	public String[] getUserList();

}
