package interfaces;

/**
 * The TMInterface interface specifies those methods which a trust/reputation
 * manager must implement in order to integrate with the QKeyNote system.
 */
public interface TMInterface{
	
	/**
	 * Given a reputation store conforming to RMDBInterface, extract the data
	 * therein, so it may be converted to a form use-able by 'this' object.
	 * @param db Reputation store conforming to RMDBInterface interface
	 */
	public void importRMData(RMDBInterface db);
	
	/**
	 * Add a user->user relationship to the TMInterface implementing object.
	 * @param source Unique string ID of the source user in the relationship
	 * @param target Unique string ID of the target user in the relationship
	 * @param pos Number of [source->target] positive interactions
	 * @param neg Number of [source->target] negative interactions
	 */
	public void addEdge(String source, String target, int pos, int neg);
	
	/**
	 * Compute trust between two parties.
	 * @param source Unique string ID of the source user
	 * @param target Unique string ID of the target user
	 * @return Trust between [source->target], or NaN if user(s) are unknown
	 */
	public double computeTrust(String source, String target);

}
