package misc;

import java.util.Random;
import interfaces.*;
import backend.*;
import quantify.*;
import TNA_SL.*;

/**
 * The Example class demonstrates a trivial example of how the RMDBInterface
 * and TMInterface interfaces can be used to manage trust. 
 */
public class Example{

	/**
	 * Driver method for the Example class.
	 * @param args None. This example takes no arguments
	 */
	public static void main(String[] args){
		
			// Create a new database object - ONLY CALL INTERFACES
		RMDBInterface rDB = new RMDatabase();

			// Add a whole bunch of random feedbacks (which will add users)
			// Our users are named "0","1","2", and "3" in this example
		Random rand = new Random();
		String source, target;
		for(int i=0; i < 1000; i++){
			source = String.valueOf(rand.nextInt(4));
			target = String.valueOf(rand.nextInt(4));
			rDB.addFeedback(source, target, rand.nextBoolean());
		}
		
			// Create a TM, in this case we'll use TNA-SL
		TMInterface tm = new TNA_Frontend();
		
			// Create a TDP, representing a delegation from KeyNote
			// In here we'll pretend that it was ("0"->"1"->"3")
		TDPath tdp = new TDPath("0");
		tdp.addArc("0", "1");
		tdp.addArc("1", "3");
		
			// Next we set up the Quantifier, and bring it all together
		Quantifier quant = new Quantifier(tdp);
		double trust = quant.quantify(rDB, tm, Quantifier.Strategy.minimum);
		// Double.compare(Double.NaN, trust);
		System.out.println("\nTrust: " + trust);
	}
	
}
